# Adding new ensembles

One of the powerful tools in OpenPathSampling is its flexible way of defining
path ensembles. To add a specialized ensemble, create a file (module) with your
new ensemble, and import any public classes/functions in the
`ensembles/__init__.py` file.
